@@ -24,6 +24,13 @@ Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
  * Interface definition for video display filters.
 **/
 
+typedef struct _MSVideoDisplayDecodingSupport MSVideoDisplayDecodingSupport;
+
+struct _MSVideoDisplayDecodingSupport {
+	const char *mime_type;	/**< Input parameter to asking if the display supports decoding of this mime type */
+	bool_t supported;	/**< Output telling whether the display supports decoding to the specified mime type */
+};
+
 /** whether the video window should be resized to the stream's resolution*/
 #define MS_VIDEO_DISPLAY_ENABLE_AUTOFIT \
 	MS_FILTER_METHOD(MSFilterVideoDisplayInterface,0,int)
@@ -58,6 +65,15 @@ Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 #define MS_VIDEO_DISPLAY_SHOW_VIDEO \
 	MS_FILTER_METHOD(MSFilterVideoDisplayInterface,9,int)
 
+#define MS_VIDEO_DISPLAY_ZOOM \
+	MS_FILTER_METHOD(MSFilterVideoDisplayInterface,10,int[4])
+
+/**Specifiy device orientation from portrait */
+#define MS_VIDEO_DISPLAY_SET_DEVICE_ORIENTATION \
+   MS_FILTER_METHOD(MSFilterVideoDisplayInterface,11,int)
+
+#define MS_VIDEO_DISPLAY_SUPPORT_DECODING \
+	MS_FILTER_METHOD(MSFilterVideoDisplayInterface, 12, MSVideoDisplayDecodingSupport*)
 
 /**
   * Interface definitions for players
@@ -73,7 +89,7 @@ typedef enum _MSPlayerState MSPlayerState;
 
 /**open a media file*/
 #define MS_PLAYER_OPEN \
-	MS_FILTER_METHOD(MSFilterPlayerInterface,0,const char *)
+	MS_FILTER_METHOD(MSFilterPlayerInterface,0,const char )
 
 #define MS_PLAYER_START \
 	MS_FILTER_METHOD_NO_ARG(MSFilterPlayerInterface,1)
@@ -88,7 +104,39 @@ typedef enum _MSPlayerState MSPlayerState;
 	MS_FILTER_METHOD(MSFilterPlayerInterface,4,int)
 
 #define MS_PLAYER_GET_STATE \
-	MS_FILTER_METHOD(MSFilterPlayerInterface,5,int)
+	MS_FILTER_METHOD(MSFilterPlayerInterface,5,MSPlayerState)
+	
+	
+
+/**
+  * Interface definitions for recorders
+**/
+
+enum _MSRecorderState{
+	MSRecorderClosed,
+	MSRecorderPaused,
+	MSRecorderRunning
+};
+
+typedef enum _MSRecorderState MSRecorderState;
+
+/**open a media file for recording*/
+#define MS_RECORDER_OPEN \
+	MS_FILTER_METHOD(MSFilterRecorderInterface,0,const char )
+
+#define MS_RECORDER_START \
+	MS_FILTER_METHOD_NO_ARG(MSFilterRecorderInterface,1)
+
+#define MS_RECORDER_PAUSE \
+	MS_FILTER_METHOD_NO_ARG(MSFilterRecorderInterface,2)
+
+#define MS_RECORDER_CLOSE \
+	MS_FILTER_METHOD_NO_ARG(MSFilterRecorderInterface,3)
+
+#define MS_RECORDER_GET_STATE \
+	MS_FILTER_METHOD(MSFilterRecorderInterface,5,MSRecorderState)
+	
+	
 
 
 /** Interface definitions for echo cancellers */
@@ -124,9 +172,42 @@ typedef enum _MSPlayerState MSPlayerState;
 /** Interface definitions for video decoders */
 #define MS_VIDEO_DECODER_DECODING_ERRORS \
 		MS_FILTER_EVENT_NO_ARG(MSFilterVideoDecoderInterface,0)
+#define MS_VIDEO_DECODER_FIRST_IMAGE_DECODED \
+        MS_FILTER_EVENT_NO_ARG(MSFilterVideoDecoderInterface,1)
+#define MS_VIDEO_DECODER_RESET_FIRST_IMAGE_NOTIFICATION \
+    MS_FILTER_METHOD_NO_ARG(MSFilterVideoDecoderInterface, 0)
 
 /** Interface definitions for video capture */
 #define MS_VIDEO_CAPTURE_SET_DEVICE_ORIENTATION \
 	MS_FILTER_METHOD(MSFilterVideoCaptureInterface,0,int)
+#define MS_VIDEO_CAPTURE_GET_CAMERA_SENSOR_ROTATION \
+	MS_FILTER_METHOD(MSFilterVideoCaptureInterface, 1, int)
+
+/** Interface definitions for audio decoder */
+
+#define MS_AUDIO_DECODER_HAVE_PLC \
+	MS_FILTER_METHOD(MSFilterAudioDecoderInterface,0,int)
+	
+#define MS_DECODER_HAVE_PLC MS_AUDIO_DECODER_HAVE_PLC /*for backward compatibility*/
+
+/** Interface definitions for video encoders */
+#define MS_VIDEO_ENCODER_HAS_BUILTIN_CONVERTER \
+	MS_FILTER_METHOD(MSFilterVideoEncoderInterface, 0, bool_t)
+/* request a video-fast-update (=I frame for H263,MP4V-ES) to a video encoder*/
+#define MS_VIDEO_ENCODER_REQ_VFU \
+	MS_FILTER_METHOD_NO_ARG(MSFilterVideoEncoderInterface, 1)
+
+/** Interface definitions for audio capture */
+/* Start numbering from the end for hacks */
+#define MS_AUDIO_CAPTURE_FORCE_SPEAKER_STATE \
+	MS_FILTER_METHOD(MSFilterAudioCaptureInterface, 255, bool_t)
+
+/** Interface definitions for audio encoder */
+#define MS_AUDIO_ENCODER_SET_PTIME \
+	MS_FILTER_METHOD(MSFilterAudioEncoderInterface,0,int)
+	
+#define MS_AUDIO_ENCODER_GET_PTIME \
+	MS_FILTER_METHOD(MSFilterAudioEncoderInterface,1,int)
+
 
 #endif
